import React from "react";
import {
  PRE_GAME,
  PRE_ROUND,
  IN_ROUND,
  POST_ROUND,
  POST_GAME,
  ERROR,
} from "../domain/GameState";
import { gameIdStore, gameStateStore } from "../domain/store";
import PreGame from "./screens/PreGame";
import PreRound from "./screens/PreRound";
import GamePanel from "./screens/GamePanel";
import RoundSummary from "./screens/RoundSummary";
import PlayerScores from "./screens/PlayerScores";
import useObservable from "../hooks/useObservable";

const componentMap = {
  [PRE_GAME]: PreGame,
  [PRE_ROUND]: PreRound,
  [IN_ROUND]: GamePanel,
  [POST_ROUND]: RoundSummary,
  [POST_GAME]: PlayerScores,
  [ERROR]: () => <p>Application encountered unrecoverable error, please refresh the page.</p>,
}

const paramRouter = {
  join: PRE_ROUND,
  summary: POST_GAME,
}

const Game = () => {
  const gameState = useObservable(gameStateStore);
  
  const url = new URL(window.location.href);
  for (let [param, value] of url.searchParams.entries()) {
    const state = paramRouter[param];
    if (state) {
      url.searchParams.delete(param);
      window.history.replaceState({}, document.title, url.href);
      gameIdStore.set(value);
      gameStateStore.set(state);
      break;
    }
  }

  const Screen = componentMap[gameState];
  return <Screen />
}

export default Game;
