import React, { useState } from 'react';
import styled from 'styled-components';
import { sendGuess } from "../../../domain/GGSHService";
import Loading from '../../util/Loading';
import GuessPane from "./GuessPane";
import PositionedStreetView from "./PositionedStreetView";
import useRoundInfo from "../../../hooks/useRoundInfo";
import { lastRoundStore, gameStateStore } from '../../../domain/store';
import { POST_ROUND, POST_GAME } from '../../../domain/GameState';

const Container = styled.div`
  height: 100%;
  width: 100%;
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;

  @media only screen and (min-width: 600px) and (min-height: 600px) {
    display: block;
    position: relative;
    margin-bottom: 2px;
    margin-right: 2px;
  }
`

const StreetViewWrapper = styled.div`
  height: 100%;
  width: 100%;
  margin-bottom: 2px;
  flex: 3;
`

const GamePanelContainer = ({ onGameEnd }) => {
  const [submitDisabled, setSubmitDisabled] = useState(false);
  const [selectedPoint, setSelectedPoint] = useState(null);
  const [finished, roundInfo] = useRoundInfo();

  if (finished) {
    gameStateStore.set(POST_GAME);
    return <Loading/>
  }

  const { currentRound, targetPoint, roundSeconds } = roundInfo;
  if (!currentRound || !targetPoint || !roundSeconds) {
    return <Loading/>
  }

  const handleSubmitGuess = async () => {
    setSubmitDisabled(true);
    const { score, totalScore } = await sendGuess(currentRound, selectedPoint || { timeout: true });
    lastRoundStore.set({
      roundNum: currentRound,
      selectedPoint,
      targetPoint,
      score,
      totalScore,
    });
    gameStateStore.set(POST_ROUND);
  }

  return (
    <Container>
      <StreetViewWrapper>
          <PositionedStreetView position={targetPoint} />
      </StreetViewWrapper>
      <GuessPane
        roundSeconds={roundSeconds}
        onTimeout={handleSubmitGuess}
        onSelectPoint={setSelectedPoint}
        onSubmitGuess={handleSubmitGuess}
        submitDisabled={submitDisabled || selectedPoint === null}
      />
    </Container>
  );
}

export default GamePanelContainer;
