import React, { useState } from "react";
import styled from "styled-components";
import Loading from "../../util/Loading";
import PlayerNameInput from "./../../util/PlayerNameInput";
import { createGame } from "../../../domain/GGSHService";
import NewGameInput from "./NewGameInput";
import useObservable from "../../../hooks/useObservable";
import { playerNameStore, gameIdStore, gameJoinedStore, gameStateStore } from "../../../domain/store";
import HeaderAndFooter from "../../util/HeaderAndFooter";
import { PRE_ROUND } from "../../../domain/GameState";

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-around;
  align-items: center;

  @media only screen and (min-width: 600px) {
    flex-flow: row nowrap;
    justify-content: space-around;
  }
`

const Divider = styled.hr`
  margin-left: 75px;
  margin-right: 75px;
  align-self: stretch;

  @media only screen and (min-width: 600px) {
    margin-left: 0;
    margin-right: 0;
    align-self: stretch;
  }
`

export default () => {
  const [loading, setLoading] = useState(false);
  const playerName = useObservable(playerNameStore);
  const [timer, setTimer] = useState(300);

  if (loading) {
    return <Loading/>
  }

  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(timer);
    gameIdStore.set(gameId);
    gameJoinedStore.set(true);
    gameStateStore.set(PRE_ROUND);
  };
  const cannotCreateGame = !playerName || playerName.length === 0;

  return (
    <HeaderAndFooter>
      <Container>
        <PlayerNameInput/>
        <Divider/>
        <NewGameInput {...{ onCreateGame, cannotCreateGame, timer, setTimer }} />
      </Container>
    </HeaderAndFooter>
  );
}
