import React from "react";
import styled from "styled-components";
import ClickToCopy from "../../util/ClickToCopy";
import usePlayerScores from "../../../hooks/usePlayerScores";
import DelayedButton from "../../util/DelayedButton";
import useRoundInfo from "../../../hooks/useRoundInfo";
import Button from "../../util/Button";
import useObservable from "../../../hooks/useObservable";
import { lastRoundStore, gameStateStore } from "../../../domain/store";
import { IN_ROUND } from "../../../domain/GameState";

const useTopScorer = (roundNum) => {
  const scores = usePlayerScores();
  const top = { topPlayer: null, topScore: null };

  if (scores === null) {
    return top;
  }

  scores
    .filter(({ guesses }) => guesses[roundNum] && guesses[roundNum].score)
    .forEach(({ name, guesses }) => {
      const score = guesses[roundNum].score;
      if (top.topScore === null || score > top.topScore) {
        top.topPlayer = name;
        top.topScore = score;
      }
    });

  return top;
}

const Container = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;

  @media only screen and (min-width: 600px) {
    margin-left: 10px;
    align-items: flex-start;
  }
`

const TimedOut = styled.span`
  color: red;
`

const FinishedButton = styled(Button)`
  margin-top: 5px;
  padding: 1em;
`

const NextButton = styled(DelayedButton)`
  margin-top: 5px;
  padding: 1em;
`

export default () => {
  const {
    roundNum,
    selectedPoint,
    targetPoint,
    score,
    totalScore,
  } = useObservable(lastRoundStore);
  const { topPlayer, topScore } = useTopScorer(roundNum);
  const [gameFinished] = useRoundInfo()
  const onNext = () => gameStateStore.set(IN_ROUND);

  return (
    <Container>
      {selectedPoint
        ? <span>
            You selected: <ClickToCopy text={`${selectedPoint.lat}, ${selectedPoint.lng}`}/>
          </span>
        : <TimedOut>Timed out!</TimedOut>
      }
      <span>Target: <ClickToCopy text={`${targetPoint.lat}, ${targetPoint.lng}`}/></span>
      <span>Score For Round {roundNum}: {score}</span>
      <span>Running Total Score: {totalScore}</span>
      {topPlayer ? <span className="round-summary__top-score">Current best is {topPlayer} with {topScore}</span> : null}
      {
        gameFinished 
          ? <FinishedButton onClick={onNext}>
              View Summary
            </FinishedButton>
          : <NextButton onEnd={onNext} countDownFormatter={rem => `Click to cancel, ${rem}s...`}>
              Next Round
            </NextButton>
      }
    </Container>
  );
}
