import { useEffect } from "react";
import flag from "../../../assets/checkered-flag.svg";
import question from "../../../assets/question-mark.svg";
/* global google */

const questionIcon = {
  url: question,
  scaledSize: new google.maps.Size(64, 64),
  origin: new google.maps.Point(0, 0),
  anchor: new google.maps.Point(32, 48),
};

const flagIcon = {
  url: flag,
  scaledSize: new google.maps.Size(32, 32),
  origin: new google.maps.Point(0, 0),
  anchor: new google.maps.Point(4, 32),
};

const lineSettings = {
  strokeColor: "#333333",
  strokeOpacity: 0,
  icons: [{
    icon: {
      path: 'M 0,-1 0,1',
      strokeOpacity: 1,
      scale: 4
    },
    offset: '0',
    repeat: '20px'
  }],
};

const openMapInNewTab = ({ lat, lng }) => {
  window.open(`https://www.google.com/maps?hl=en&q=+${lat},+${lng}`, "_blank");
}

const makeMarker = (map, position, title, icon) => {
  const marker = new google.maps.Marker({
    clickable: true,
    map,
    position,
    title,
    icon,
  });

  marker.addListener("click", () => openMapInNewTab(position));

  return marker;
}

export default (mapRef, selectedPoint, targetPoint) => {
  useEffect(() => {
    const selectedMarker = selectedPoint
      ? makeMarker(mapRef.current, selectedPoint, "Selected", questionIcon)
      : null;
    const targetMarker = makeMarker(mapRef.current, targetPoint, "Goal", flagIcon);

    const line = selectedPoint
      ? new google.maps.Polyline({
        path: [ selectedPoint, targetPoint ],
        map: mapRef.current,
        ...lineSettings,
      })
      : null;

    return () => {
      if (line) {
        line.setMap(null);
      }
      targetMarker.setMap(null);
      if (selectedMarker) {
        selectedMarker.setMap(null);
      }
    }
  }, [mapRef, selectedPoint, targetPoint]);
}
