import { playerNameStore, gameIdStore } from "./store";

const API_BASE = "https://kirkleon.ddns.net/terrassumptions/api";

export const getStatus = async () => {
    try {
        const res = await fetch(API_BASE);
        if (!res.ok) {
            throw Error(res.statusText);
        }
        return await res.json();
    } catch (err) {
        return {status: err.message, version: null}
    }
}

export const createGame = async (timer) => {
    const name = playerNameStore.get();
    const res = await fetch(`${API_BASE}/game`, {
        method: "PUT",
        headers: {
            "Authorization": `Name ${name}`,
            "Content-Type": "application/json",
        },
        body: JSON.stringify({ timer }),
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    const { gameId } = await res.json();
    return gameId;
}

export const gameInfo = async () => {
    const gameId = gameIdStore.get();
    const res = await fetch(`${API_BASE}/game/${gameId}`);
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}

export const joinGame = async () => {
    const gameId = gameIdStore.get();
    const name = playerNameStore.get();
    const res = await fetch(`${API_BASE}/game/${gameId}/join`, {
        method: "POST",
        headers: {
            "Authorization": `Name ${name}`
        },
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
}

export const getCurrentRound = async () => {
    const gameId = gameIdStore.get();
    const name = playerNameStore.get();
    const res = await fetch(`${API_BASE}/game/${gameId}/current`, {
        headers: {
            "Authorization": `Name ${name}`
        },
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}

export const sendGuess = async (round, point) => {
    const gameId = gameIdStore.get();
    const name = playerNameStore.get();
    const res = await fetch(`${API_BASE}/game/${gameId}/guesses/${round}`, {
        method: "POST",
        headers: {
            "Authorization": `Name ${name}`,
            "Content-Type": "application/json",
        },
        body: JSON.stringify(point),
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}
